Py-ART Continuous Integration Setup
===================================

Py-ART makes use of continuous integration (CI) to run the library's unit tests
against every pull request and change made to the repository. This document
gives a brief explanation of the details of this setup and hints on how to fix
the CI when it breaks.
